<!-- markdownlint-disable -->

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\string_builder.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.string_builder`






---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\string_builder.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `Builder`
Utility class for incrementally building strings. 

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\string_builder.py#L9"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Builder.__init__`

```python
__init__(
    out: Optional[Callable[[str], NoneType]] = None,
    indent: int = 4,
    endl: str = '\n'
)
```








---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\string_builder.py#L37"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Builder.join`

```python
join(base: str = '')
```





---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\string_builder.py#L31"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `Builder.line`

```python
line(string: str = '')
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
